"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initConfig = exports.readConfig = exports.validateConfig = exports.GLOBAL_CONFIG_FILE = void 0;
const fs_1 = __importDefault(require("fs"));
exports.GLOBAL_CONFIG_FILE = {
    out: './src',
    in: './content',
};
const validateConfig = (config) => {
    const errors = [];
    Object.keys(exports.GLOBAL_CONFIG_FILE).forEach((key) => {
        const v = config[key];
        if (typeof v === 'undefined' || v === null) {
            errors.push(`Invalid config file. Please include "${key}" in your config`);
        }
    });
    if (errors.length > 0) {
        throw new Error(errors.join('\n'));
    }
};
exports.validateConfig = validateConfig;
const readConfig = (path) => {
    const configExists = fs_1.default.existsSync(path);
    if (!configExists) {
        throw new Error('No config for mdtx please create one using init');
    }
    try {
        const config = JSON.parse(fs_1.default.readFileSync(path).toString('utf8'));
        (0, exports.validateConfig)(config);
        return config;
    }
    catch (error) {
        throw new Error('Invalid JSON file');
    }
};
exports.readConfig = readConfig;
const initConfig = () => __awaiter(void 0, void 0, void 0, function* () {
    fs_1.default.writeFileSync('mdtx.json', JSON.stringify(exports.GLOBAL_CONFIG_FILE, null, 4));
});
exports.initConfig = initConfig;
//# sourceMappingURL=config.js.map