"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fileTouchSync = exports.fileWriteRecuirsiveIfContentDifferent = exports.fileWriteRecuirsiveAsync = exports.existsJSONOrDefaultSync = exports.mkFileDirSync = exports.isStaticFile = exports.getPossibleFilePaths = exports.mayBeIndexFileOrWithoutExtension = exports.isDirectory = exports.isEnv = exports.isMd = exports.fileRegex = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
exports.fileRegex = /(.*)\.js$/;
const mdRegex = /(.*)\.md$/;
const envRegex = /^\.env/;
const isMd = (p) => !!p.match(mdRegex);
exports.isMd = isMd;
const isEnv = (p) => !!p.match(envRegex);
exports.isEnv = isEnv;
const isDirectory = (p) => fs_1.default.statSync(p).isDirectory();
exports.isDirectory = isDirectory;
const mayBeIndexFileOrWithoutExtension = (p) => {
    if (p.includes('.')) {
        return !p
            .split('.')
            .pop()
            .match(/[^\/]*/gm);
    }
    return !p.match(/\/$/);
};
exports.mayBeIndexFileOrWithoutExtension = mayBeIndexFileOrWithoutExtension;
const getPossibleFilePaths = (p) => [
    '.ts',
    '.tsx',
    '.js',
    '.jsx',
    '/index.ts',
    '/index.tsx',
    '/index.js',
    '/index.jsx',
].map((e) => `${p}${e}`);
exports.getPossibleFilePaths = getPossibleFilePaths;
const isStaticFile = (p) => !(0, exports.isMd)(p) && !(0, exports.isEnv)(p);
exports.isStaticFile = isStaticFile;
const mkFileDirSync = (p) => __awaiter(void 0, void 0, void 0, function* () {
    const dir = path_1.default.dirname(p);
    if (!fs_1.default.existsSync(dir)) {
        yield fs_1.default.promises.mkdir(dir, { recursive: true });
    }
});
exports.mkFileDirSync = mkFileDirSync;
const existsJSONOrDefaultSync = (p, defaultValue) => fs_1.default.existsSync(p)
    ? JSON.parse(fs_1.default.readFileSync(p).toString('utf-8'))
    : defaultValue;
exports.existsJSONOrDefaultSync = existsJSONOrDefaultSync;
const fileWriteRecuirsiveAsync = (p, data) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, exports.mkFileDirSync)(p);
    fs_1.default.promises.writeFile(p, data);
});
exports.fileWriteRecuirsiveAsync = fileWriteRecuirsiveAsync;
const fileWriteRecuirsiveIfContentDifferent = (p, data) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, exports.mkFileDirSync)(p);
    if (fs_1.default.existsSync(p)) {
        const content = (yield fs_1.default.promises.readFile(p)).toString('utf-8');
        if (content !== data) {
            return fs_1.default.promises.writeFile(p, data);
        }
    }
    return fs_1.default.promises.writeFile(p, data);
});
exports.fileWriteRecuirsiveIfContentDifferent = fileWriteRecuirsiveIfContentDifferent;
const fileTouchSync = (p) => {
    const time = new Date();
    try {
        fs_1.default.utimesSync(p, time, time);
    }
    catch (err) {
        fs_1.default.closeSync(fs_1.default.openSync(p, 'w'));
    }
};
exports.fileTouchSync = fileTouchSync;
//# sourceMappingURL=fsAddons.js.map